use database::DatabaseHandler;

#[macro_use]
extern crate rocket;

mod api;
mod database;

#[rocket::main]
async fn main() {
    let db = match DatabaseHandler::create().await {
        Ok(client) => client,
        Err(err) => panic!(
            "Encountered an error while connecting to the database!\n{}",
            err
        ),
    };

    match rocket::build()
        .manage(db)
        .mount("/api/v1/maps", api::maps::get_all_routes())
        .mount("/api/v1/races", api::races::get_all_routes())
        .mount("/api/v1/teamraces", api::teamraces::get_all_routes())
        .launch()
        .await
    {
        Ok(_) => (),
        Err(err) => println!("Encountered an error while starting rocket!\n{}", err),
    }
}
